@@ -12,7 +12,7 @@ from deckz import app_name
 _logger = getLogger(__name__)
 
 
-class Paths:
+class _Paths:
     def __init__(self, working_dir: str) -> None:
         self.working_dir = Path(working_dir).resolve()
         self.build_dir = self.working_dir / "build"
@@ -21,6 +21,8 @@ class Paths:
         self.shared_img_dir = self.shared_dir / "img"
         self.shared_code_dir = self.shared_dir / "code"
         self.shared_latex_dir = self.shared_dir / "latex"
+        self.templates_dir = self.git_dir / "templates"
+        self.template_latex = self.templates_dir / "subsection.tex"
         self.jinja2_dir = self.git_dir / "jinja2"
         self.user_config_dir = Path(user_config_dir(app_name))
         self.global_config = self.git_dir / "global-config.yml"
@@ -57,3 +59,6 @@ class Paths:
 
     def get_jinja2_template_path(self, version: str) -> Path:
         return self.jinja2_dir / f"{version}.tex.jinja2"
+
+
+paths = _Paths(".")
